@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,6 +20,7 @@ import org.apache.commons.compress.archivers.ar.ArArchiveEntry;
 import org.apache.commons.compress.archivers.ar.ArArchiveOutputStream;
 import org.apache.commons.compress.archivers.tar.TarArchiveEntry;
 import org.apache.commons.io.FileUtils;
+import org.apache.commons.io.FilenameUtils;
 import org.apache.commons.io.IOUtils;
 import org.bouncycastle.bcpg.HashAlgorithmTags;
 import org.bouncycastle.crypto.digests.MD5Digest;
@@ -118,6 +119,12 @@ public class DebMaker {
     /** Defines the role to sign with */
     private String signRole;
 
+    /** Defines the longFileMode of the tar file that is built */
+    private String tarLongFileMode;
+
+    /** Defines the bigNumberMode of the tar file that is built */
+    private String tarBigNumberMode;
+
     private VariableResolver variableResolver;
     private String openReplaceToken;
     private String closeReplaceToken;
@@ -227,6 +234,14 @@ public class DebMaker {
         this.digest = digest;
     }
 
+    public void setTarLongFileMode(String tarLongFileMode) {
+        this.tarLongFileMode = tarLongFileMode;
+    }
+
+    public void setTarBigNumberMode(String tarBigNumberMode) {
+        this.tarBigNumberMode = tarBigNumberMode;
+    }
+
     /**
      * Validates the input parameters.
      */
@@ -338,7 +353,7 @@ public class DebMaker {
 
     private void makeChangesFiles(final BinaryPackageControlFile packageControlFile) throws PackagingException {
         if (changesOut == null) {
-            changesOut = new File(deb.getParentFile(), deb.getName().replace(".deb", ".changes"));
+            changesOut = new File(deb.getParentFile(), FilenameUtils.getBaseName(deb.getName()) + ".changes");
         }
 
         ChangesProvider changesProvider;
@@ -467,7 +482,11 @@ public class DebMaker {
             console.debug("Building data");
             DataBuilder dataBuilder = new DataBuilder(console);
             StringBuilder md5s = new StringBuilder();
-            BigInteger size = dataBuilder.buildData(dataProducers, tempData, md5s, compression);
+            TarOptions options = new TarOptions()
+                .compression(compression)
+                .longFileMode(tarLongFileMode)
+                .bigNumberMode(tarBigNumberMode);
+            BigInteger size = dataBuilder.buildData(dataProducers, tempData, md5s, options);
 
             console.info("Building conffiles");
             List<String> tempConffiles = populateConffiles(conffilesProducers);
