@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,9 +16,6 @@
 
 package org.vafer.jdeb.maven;
 
-import static org.vafer.jdeb.utils.Utils.lookupIfEmpty;
-import static org.vafer.jdeb.utils.Utils.isBlank;
-
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
@@ -58,10 +55,13 @@ import org.vafer.jdeb.utils.SymlinkUtils;
 import org.vafer.jdeb.utils.Utils;
 import org.vafer.jdeb.utils.VariableResolver;
 
+import static org.vafer.jdeb.utils.Utils.isBlank;
+import static org.vafer.jdeb.utils.Utils.lookupIfEmpty;
+
 /**
  * Creates Debian package
  */
-@Mojo(name = "jdeb", defaultPhase = LifecyclePhase.PACKAGE)
+@Mojo(name = "jdeb", defaultPhase = LifecyclePhase.PACKAGE, threadSafe = true)
 public class DebMojo extends AbstractMojo {
 
     @Component
@@ -338,6 +338,20 @@ public class DebMojo extends AbstractMojo {
     @Parameter(defaultValue = "")
     private String propertyPrefix;
 
+    /**
+     * Sets the long file mode for the resulting tar file.  Valid values are "gnu", "posix", "error" or "truncate"
+     * @see org.apache.commons.compress.archivers.tar.TarArchiveOutputStream#setLongFileMode(int)
+     */
+    @Parameter(defaultValue = "gnu")
+    private String tarLongFileMode;
+
+    /**
+     * Sets the big number mode for the resulting tar file.  Valid values are "gnu", "posix" or "error"
+     * @see org.apache.commons.compress.archivers.tar.TarArchiveOutputStream#setBigNumberMode(int)
+     */
+    @Parameter(defaultValue = "gnu")
+    private String tarBigNumberMode;
+
     /* end of parameters */
 
     private static final String KEY = "key";
@@ -563,6 +577,8 @@ public class DebMojo extends AbstractMojo {
             debMaker.setOpenReplaceToken(openReplaceToken);
             debMaker.setCloseReplaceToken(closeReplaceToken);
             debMaker.setDigest(digest);
+            debMaker.setTarBigNumberMode(tarBigNumberMode);
+            debMaker.setTarLongFileMode(tarLongFileMode);
             debMaker.validate();
             debMaker.makeDeb();
 
