@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,19 +20,22 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.util.Arrays;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+import org.junit.Assert;
+
 import org.apache.commons.compress.archivers.tar.TarArchiveInputStream;
 import org.apache.tools.ant.Project;
 import org.apache.tools.ant.types.FileSet;
 import org.vafer.jdeb.producers.DataProducerFile;
 import org.vafer.jdeb.producers.DataProducerFileSet;
 
-public class DataBuilderTestCase extends TestCase {
+public final class DataBuilderTestCase extends Assert {
 
     /**
      * Checks if the file paths in the md5sums file use only unix file separators
      * (this test can only fail on Windows)
      */
+    @Test
     public void testBuildDataWithFileSet() throws Exception {
         DataBuilder builder = new DataBuilder(new NullConsole());
 
@@ -46,13 +49,14 @@ public class DataBuilderTestCase extends TestCase {
         fileset.setProject(project);
 
         StringBuilder md5s = new StringBuilder();
-        builder.buildData(Arrays.asList((DataProducer) new DataProducerFileSet(fileset)), new File("target/data.tar"), md5s, Compression.GZIP);
+        builder.buildData(Arrays.asList((DataProducer) new DataProducerFileSet(fileset)), new File("target/data.tar"), md5s, new TarOptions().compression(Compression.GZIP));
 
         assertTrue("empty md5 file", md5s.length() > 0);
         assertFalse("windows path separator found", md5s.indexOf("\\") != -1);
-        assertTrue("two spaces between md5 and file", md5s.toString().equals("8bc944dbd052ef51652e70a5104492e3  ./test/testfile\n"));
+        assertTrue("two spaces between md5 and file, no leading slash, or dot, on file path", md5s.toString().equals("8bc944dbd052ef51652e70a5104492e3  test/testfile\n"));
     }
 
+    @Test
     public void testCreateParentDirectories() throws Exception {
         File archive = new File("target/data.tar");
         if (archive.exists()) {
@@ -63,7 +67,7 @@ public class DataBuilderTestCase extends TestCase {
 
         DataProducer producer = new DataProducerFile(new File("pom.xml"), "/usr/share/myapp/pom.xml", null, null, null);
 
-        builder.buildData(Arrays.asList(producer), archive, new StringBuilder(), Compression.NONE);
+        builder.buildData(Arrays.asList(producer), archive, new StringBuilder(), new TarOptions().compression(Compression.NONE));
 
         int count = 0;
         TarArchiveInputStream in = null;
