@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -16,11 +16,14 @@
 
 package org.vafer.jdeb.ant;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+import org.junit.Assert;
+
 import org.apache.tools.ant.types.selectors.SelectorUtils;
 
-public final class AntSelectorTestCase extends TestCase {
+public final class AntSelectorTestCase extends Assert {
 
+    @Test
     public void testExclusion() throws Exception {
         assertTrue("should match",
             SelectorUtils.matchPath("**/bin/**", "/some/bin/stuff"));
