@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 The jdeb developers.
+ * Copyright 2007-2018 The jdeb developers.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -20,11 +20,14 @@ import java.io.ByteArrayOutputStream;
 import java.io.InputStream;
 import java.util.Arrays;
 
-import junit.framework.TestCase;
+import org.junit.Test;
+import org.junit.Assert;
+
 import org.bouncycastle.openpgp.PGPUtil;
 
-public final class PGPSignerTestCase extends TestCase {
+public final class PGPSignerTestCase extends Assert {
 
+    @Test
     public void testClearSign() throws Exception {
 
         final InputStream ring = getClass().getClassLoader().getResourceAsStream("org/vafer/gpg/secring.gpg");
@@ -42,7 +45,7 @@ public final class PGPSignerTestCase extends TestCase {
                 "\n" +
                 "TEST3\n" +
                 "-----BEGIN PGP SIGNATURE-----\n" +
-                "Version: BCPG v1.53\n" +
+                "Version: BCPG v1.58\n" +
                 "\n" +
                 "iEYEARECABAFAkax1rgJEHM9pIAuB02PAABIJgCghFmoCJCZ0CGiqgVLGGPd/Yh5\n" +
                 "FQQAnRVqvI2ij45JQSHYJBblZ0Vv2meN\n" +
@@ -65,6 +68,7 @@ public final class PGPSignerTestCase extends TestCase {
         assertEquals(new String(expectedOutput), new String(output));
     }
 
+    @Test
     public void testKeyLoading() throws Exception {
         InputStream ring = getClass().getClassLoader().getResourceAsStream("org/vafer/gpg/secring.gpg");
         PGPSigner signer = new PGPSigner(ring, "2E074D8F", "test", PGPUtil.SHA1);
